@@ -1,6 +1,7 @@
 from collections import UserDict
 from typing import Any
 
+from contextvars import copy_context
 from starlette_context import _request_scope_context_storage
 
 
@@ -32,6 +33,9 @@ class _Context(UserDict):
                 "outside of the request-response cycle."
             ) from e
 
+    def exists(self) -> bool:
+        return _request_scope_context_storage in copy_context()
+
     def copy(self) -> dict:
         """
         Read only context data.
